ExecutorBuilder

Trait ExecutorBuilder 

pub trait ExecutorBuilder<Node: FullNodeTypes>: Send {
    type EVM: ConfigureEvm<Primitives = PrimitivesTy<Node::Types>> + 'static;

    // Required method
    fn build_evm(
        self,
        ctx: &BuilderContext<Node>,
    ) -> impl Future<Output = Result<Self::EVM>> + Send;
}
A type that knows how to build the executor types.

Required Associated Types

type EVM: ConfigureEvm<Primitives = PrimitivesTy<Node::Types>> + 'static

The EVM config to use.

This provides the node with the necessary configuration to configure an EVM.

Required Methods

fn build_evm( self, ctx: &BuilderContext<Node>, ) -> impl Future<Output = Result<Self::EVM>> + Send

Creates the EVM config.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<Node, F, Fut, EVM> ExecutorBuilder<Node> for F
where Node: FullNodeTypes, EVM: ConfigureEvm<Primitives = PrimitivesTy<Node::Types>> + 'static, F: FnOnce(&BuilderContext<Node>) -> Fut + Send, Fut: Future<Output = Result<EVM>> + Send,

Source

type EVM = EVM