pub trait NetworkBuilder<Node: FullNodeTypes, Pool: TransactionPool>: Send {
type Network: FullNetwork<Primitives: NetPrimitivesFor<PrimitivesTy<Node::Types>>>;
// Required method
fn build_network(
self,
ctx: &BuilderContext<Node>,
pool: Pool,
) -> impl Future<Output = Result<Self::Network>> + Send;
}Expand description
A type that knows how to build the network implementation.
Required Associated Types
Sourcetype Network: FullNetwork<Primitives: NetPrimitivesFor<PrimitivesTy<Node::Types>>>
type Network: FullNetwork<Primitives: NetPrimitivesFor<PrimitivesTy<Node::Types>>>
The network built.
Required Methods
Sourcefn build_network(
self,
ctx: &BuilderContext<Node>,
pool: Pool,
) -> impl Future<Output = Result<Self::Network>> + Send
fn build_network( self, ctx: &BuilderContext<Node>, pool: Pool, ) -> impl Future<Output = Result<Self::Network>> + Send
Launches the network implementation and returns the handle to it.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".