pub trait PayloadServiceBuilder<Node: FullNodeTypes, Pool: TransactionPool, EvmConfig>: Send + Sized {
// Required method
fn spawn_payload_builder_service(
self,
ctx: &BuilderContext<Node>,
pool: Pool,
evm_config: EvmConfig,
) -> impl Future<Output = Result<PayloadBuilderHandle<<Node::Types as NodeTypes>::Payload>>> + Send;
}Expand description
A type that knows how to spawn the payload service.
Required Methods
Sourcefn spawn_payload_builder_service(
self,
ctx: &BuilderContext<Node>,
pool: Pool,
evm_config: EvmConfig,
) -> impl Future<Output = Result<PayloadBuilderHandle<<Node::Types as NodeTypes>::Payload>>> + Send
fn spawn_payload_builder_service( self, ctx: &BuilderContext<Node>, pool: Pool, evm_config: EvmConfig, ) -> impl Future<Output = Result<PayloadBuilderHandle<<Node::Types as NodeTypes>::Payload>>> + Send
Spawns the [PayloadBuilderService] and returns the handle to it for use by the engine.
We provide default implementation via [BasicPayloadJobGenerator] but it can be overridden
for custom job orchestration logic,
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".